@@ -1,6 +1,6 @@
-/*	$Id: Files.c,v 1.22 2002/02/15 22:01:59 ooc-devel Exp $	*/
+/*	$Id: Files.c,v 1.20 2000/09/23 19:40:08 ooc-devel Exp $	*/
 /*  Access to files and file attributes.
-    Copyright (C) 1997-2000, 2002  Michael van Acken
+    Copyright (C) 1997-2000  Michael van Acken
 
     This module is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public License
@@ -507,33 +507,7 @@ void Files__FileDesc_Register(Files__File f) {
 		PERMISSIONS_REGISTER & ~active_umask);
     
     if (res != -1) {	/* rename file atomically */
-#if defined(__MINGW32__) || defined(__CYGWIN32__)
-    /* Windows file semantics do not allow open files to be renamed or files
-       to be renamed over existing files. Hence the following ... [sg] */
-    /* Note: This code should also be used under Cygwin for Win9X platforms.
-       Cygwin emulation of unix semantics only seems to work under WinNT. [sg]*/
-
-      res = close(f->fd);
-      if (res != -1) {
-        f->fd = -1;
-        /* Remove the file if it already exists */
-	if (access(f->name, 0)==0) {
-          res = unlink(f->name);
-        }
-        /* Rename and then reopen the file */
-        if (res != -1) {
-          res = rename(f->tmpName, f->name);
-          if (res != -1) {
-            /* Hmmm. We should have stored the old mode & permissions to use
-               again here. [sg] */
-            res = open_file(f->name, O_RDWR, S_IREAD | S_IWRITE);
-            f->fd = res;
-          }
-        }
-      }
-#else
-       res = rename((const char*)f->tmpName, (const char*)f->name);
-#endif
+      res = rename((const char*)f->tmpName, (const char*)f->name);
     }
     
     if (res == -1) {
@@ -597,7 +571,7 @@ void Files__FileDesc_Close(Files__File f) {
 }
 
 void Files__WriterDesc_Truncate(Files__Writer w, int newLength) {
-  PosixFileDescr__Truncate ((PosixFileDescr__Writer)w, newLength);
+  PosixFileDescr__Truncate ((PosixFileDescr__Writer)w->base, newLength);
 }
 
 #define NO_ERROR ((fd == -2) || ((fd == -1) && (errno == EACCES)))
