@@ -19,9 +19,9 @@ static const struct {
   void* pad;
   const char name[6];
 } _n0 = {6, NULL, {"Types"}};
-static struct _MD Types__md = {
+static struct _MD Types_md = {
   NULL, 
-  &Kernel_ModuleDesc__td.td, 
+  &Kernel__ModuleDesc_td.td, 
   {
     NULL, 
     (const unsigned char*)_n0.name, 
@@ -31,7 +31,7 @@ static struct _MD Types__md = {
 };
 
 
-Types_Type Types_BaseOf (Types_Type t, INTEGER level) {
+Types__Type Types_BaseOf (Types__Type t, INTEGER level) {
   if ((0 <= level) && (level <= t->level)) {
     return t->btypes[level];
   } else {
@@ -39,23 +39,23 @@ Types_Type Types_BaseOf (Types_Type t, INTEGER level) {
   }
 }
 
-INTEGER Types_LevelOf (Types_Type t) {
+INTEGER Types_LevelOf (Types__Type t) {
   return t->level;
 }
 
-void Types_NewObj (PTR (* o), Types_Type t) {
+void Types_NewObj (PTR (* o), Types__Type t) {
   char* mem = GC_malloc(t->size+OFFSET_PTR);
   char* var = mem+OFFSET_PTR;
 
 #if !USE_GC
   (void)memset((void*)mem, 0, t->size+OFFSET_PTR);
 #endif
-  ((Types_Type*)var)[-1] = t;
+  ((Types__Type*)var)[-1] = t;
   *o = var;
 }
 
-Types_Type Types_This (Kernel_Module mod, const CHAR *name) {
-  Types_Type td = (Types_Type)mod->tdescs;
+Types__Type Types_This (Kernel__Module mod, const OOC_CHAR *name) {
+  Types__Type td = (Types__Type)mod->tdescs;
   while (td) {
     if (!strcmp((const char*)name, (const char*)td->name)) {
       return td;
@@ -65,12 +65,12 @@ Types_Type Types_This (Kernel_Module mod, const CHAR *name) {
   return NULL;
 }
 
-Types_Type Types_TypeOf (PTR o) {
-  return ((Types_Type*)o)[-1];
+Types__Type Types_TypeOf (PTR o) {
+  return ((Types__Type*)o)[-1];
 }
 
-void Types__init (void) {
-  _mid = _register_module (&Types__md.md, NULL);
+void Types_init (void) {
+  _mid = _register_module (&Types_md.md, NULL);
 }
 
 
